==> image-editor_1.0.11.orig.tar.xz: image-editor-1.0.11/libimageviewer/translations/libimageviewer_pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt" version="2.1">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Informação da imagem</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Informação básica</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalhes</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>Adicionar ao álbum</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Novo álbum</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Todas as imagens</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Abrir imagem</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Remover do álbum</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Remover dos favoritos</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Adicionar aos favoritos</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Não tem permissões para ver a imagem</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Data de modificação</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Tamanho do ficheiro</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Data capturada</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Modo de exposição</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Programa de exposição</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Tempo de exposição</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Flash</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Abertura</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Comprimento focal</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Abertura máxima</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Modo de medição</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Equilíbrio de brancos</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Compensação de flash</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Modelo da lente</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Espaço de cores</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Modelo da câmara</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Dimensões</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Etiqueta</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Próximo</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Tamanho 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Ajustar à janela</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Extrair texto</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rodar para a esquerda</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rodar para a direita</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Sair de ecrã inteiro</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Ecrã inteiro</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Apresentação</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Mostrar janela de navegação</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Ocultar janela de navegação</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Definir como papel de parede</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Mostrar no gestor de ficheiros</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informação da imagem</translation>
    </message>
    <message>
        <source>day</source>
        <translation>dia</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Introduza um novo nome</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproduzir</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Próximo</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Nenhum ficheiro de imagem encontrado</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Ficheiro de imagem não encontrado</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation>Não tem permissões para ver o ficheiro</translation>
    </message>
</context>
</TS>

==> image-editor_1.0.21.orig.tar.xz: image-editor-1.0.21/libimageviewer/translations/libimageviewer_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Informação da imagem</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Informação básica</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalhes</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>Adicionar ao álbum</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Novo álbum</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Todas as imagens</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Abrir imagem</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Remover do álbum</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Remover dos favoritos</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Adicionar aos favoritos</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Não tem permissões para ver a imagem</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Data de modificação</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Tamanho do ficheiro</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Data capturada</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Modo de exposição</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Programa de exposição</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Tempo de exposição</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Flash</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Abertura</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Comprimento focal</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Abertura máxima</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Modo de medição</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Equilíbrio de brancos</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Compensação de flash</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Modelo da lente</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Espaço de cores</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Modelo da câmara</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Dimensões</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Etiqueta</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Próximo</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Tamanho 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Ajustar à janela</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Extrair texto</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rodar para a esquerda</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rodar para a direita</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Sair de ecrã inteiro</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Ecrã inteiro</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Apresentação</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Mostrar janela de navegação</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Ocultar janela de navegação</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Definir como papel de parede</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Mostrar no gestor de ficheiros</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informação da imagem</translation>
    </message>
    <message>
        <source>day</source>
        <translation>dia</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Introduza um novo nome</translation>
    </message>
    <message>
        <source>The file already exists, please use another name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproduzir</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Próximo</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Nenhum ficheiro de imagem encontrado</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Ficheiro de imagem não encontrado</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation>Não tem permissões para ver o ficheiro</translation>
    </message>
</context>
</TS>
